/**
 * Your extension ID to specify your extension when sending the message.
 * For information on how to generate your own extension ID see here: https://stackoverflow.com/a/46739698
 * Once you have your key generated, you can add the key to your manifest.json under the "key" property.
 * If you have not set the ID properly, or made this webpage externally connectable you will get the following error:
 * `Unchecked runtime.lastError: Could not establish connection. Receiving end does not exist.`
 */
const extensionID = "aokkbecooohkgppimfffkongjlpihbol";

/**
 * Only here to make sure you are on the correct browser.
 */
const isChromeApiAccessible =
  typeof window.chrome !== "undefined" &&
  typeof window.chrome.runtime !== "undefined" &&
  typeof window.chrome.runtime.sendMessage !== "undefined";

const submitButton = document.querySelector("button");
const inputElement = document.querySelector("input");
/**
 * Wrapped in an IFFE to stop execution when needed
 */
(() => {
  try {
    if (!isChromeApiAccessible) {
      return console.log("Stopping execution, chrome api is not accessible.");
    }
    window.chrome.runtime.sendMessage(
      extensionID,
      { status: "PING" },
      (isConnected) => {
        if (!isConnected) {
          return console.log(
            "Stopping execution, failed to connect to the extension"
          );
        }
        console.log("Successfully pinged extension, ready to accept code");
        submitButton.disabled = false;
        inputElement.disabled = false;
        submitButton.onclick = () => {
          const code = inputElement.value;
          window.chrome.runtime.sendMessage(
            extensionID,
            { status: "SET_TRACKING_CODE", payload: { code } },
            (wasSuccessful) => {
              if (!wasSuccessful) {
                return console.log("Failed to send code");
              }
              console.log("Successfully sent code");
            }
          );
        };
      }
    );
  } catch (err) {
    console.error("Failed to communicate with the extension", err);
  }
})();
